@@ -34,7 +34,7 @@ from coordio import (
     Wok,
 )
 from coordio import __version__ as coordio_version
-from coordio.defaults import FOCAL_SCALE, INST_TO_WAVE, POSITIONER_HEIGHT, calibration
+from coordio.defaults import INST_TO_WAVE, POSITIONER_HEIGHT, calibration
 from kaiju import __version__ as kaiju_version
 from sdssdb.peewee.sdss5db import opsdb, targetdb
 
@@ -53,6 +53,7 @@ from jaeger.kaiju import (
     warn,
 )
 from jaeger.utils import get_sjd
+from jaeger.utils.database import connect_database
 from jaeger.utils.helpers import run_in_executor
 
 from .tools import copy_summary_file, positioner_to_wok, wok_to_positioner
@@ -153,7 +154,7 @@ class BaseConfiguration:
         self.configuration_id: int | None = None
         self._summary_file: str | None = None
 
-        self.scale = scale or FOCAL_SCALE
+        self.scale = scale or 1.0
 
         # Whether the configuration is a dither. If True, there will be a base
         # configuration from which we dithered and the trajectory will be applied
@@ -586,6 +587,9 @@ class BaseConfiguration:
     def write_to_database(self, replace=False):
         """Writes the configuration to the database."""
 
+        if connect_database(targetdb.database) is False:
+            raise RuntimeError("Cannot connect to database.")
+
         if "admin" in targetdb.database._config:
             targetdb.database.become_admin()
 
@@ -734,8 +738,13 @@ class BaseConfiguration:
             right_index=True,
         ).set_index("positionerID_x")
 
-        fdata.loc[(fass.index, "APOGEE"), "fiberId"] = fass.APOGEEFiber.tolist()
-        fdata.loc[(fass.index, "BOSS"), "fiberId"] = fass.BOSSFiber.tolist()
+        fdata.loc[
+            (fass.index, "APOGEE"), "fiberId"
+        ] = fass.APOGEEFiber.tolist()  # type:ignore
+
+        fdata.loc[
+            (fass.index, "BOSS"), "fiberId"
+        ] = fass.BOSSFiber.tolist()  # type:ignore
 
         fdata.fillna(-999, inplace=True)
 
@@ -942,11 +951,15 @@ class DitheredConfiguration(BaseConfiguration):
         epoch: float | None = None,
     ):
 
-        self.parent_configuration = parent_configuration
-        assert self.parent_configuration.design
+        assert parent_configuration.design
 
         super().__init__(scale=parent_configuration.scale)
 
+        # This needs to be set after the __init__ beccause __init__ sets
+        # parent_configuration=None.
+        self.parent_configuration = parent_configuration
+        assert self.parent_configuration.design
+
         self.is_dither = True
 
         self.design = self.parent_configuration.design
@@ -1238,7 +1251,7 @@ class BaseAssignmentData:
         self.site = Site(self.observatory)
         self.site.set_time()
 
-        self.scale = scale or FOCAL_SCALE
+        self.scale = scale or 1.0
 
         positionerTable = calibration.positionerTable
         wokCoords = calibration.wokCoords
@@ -1590,7 +1603,9 @@ class BaseAssignmentData:
         row.update(kwargs)
 
         if update:
-            self.fibre_table.loc[(positioner_id, fibre_type), row.keys()] = row
+            self.fibre_table.loc[
+                (positioner_id, fibre_type), row.keys()
+            ] = row  # type:ignore
 
         return row
 
@@ -1666,7 +1681,9 @@ class BaseAssignmentData:
         row.update(kwargs)
 
         if update:
-            self.fibre_table.loc[(positioner_id, fibre_type), row.keys()] = row
+            self.fibre_table.loc[
+                (positioner_id, fibre_type), row.keys()
+            ] = row  # type:ignore
 
         return row
 
