@@ -15,6 +15,8 @@ import re
 from typing import TYPE_CHECKING
 
 import numpy
+import pandas
+from pydl.pydlutils.sdss import yanny
 
 from coordio.conv import (
     positionerToTangent,
@@ -38,7 +40,12 @@ if TYPE_CHECKING:
     from jaeger import FPS
 
 
-__all__ = ["wok_to_positioner", "positioner_to_wok", "copy_summary_file"]
+__all__ = [
+    "wok_to_positioner",
+    "positioner_to_wok",
+    "copy_summary_file",
+    "read_confSummary",
+]
 
 
 def wok_to_positioner(
@@ -164,6 +171,8 @@ async def create_random_configuration(
     collision_buffer: float | None = None,
     max_deadlocks: int = 6,
     deadlock_retries: int = 5,
+    n_failed: int = 0,
+    max_retries: int = 5,
     **kwargs,
 ):
     """Creates a random configuration using Kaiju."""
@@ -193,7 +202,7 @@ async def create_random_configuration(
         else:
             if safe:
                 safe_mode = config["safe_mode"]
-                if safe_mode is False:
+                if isinstance(safe_mode, bool) or safe_mode is None:
                     safe_mode = {"min_beta": 165, "max_beta": 175}
 
                 robot.setAlphaBeta(
@@ -225,6 +234,9 @@ async def create_random_configuration(
     # If too many deadlocks, just try a new seed.
     n_deadlock = len(deadlocks)
     if did_fail and n_deadlock > max_deadlocks:
+        if n_failed >= max_retries:
+            raise JaegerError("Reached the limit of retries.")
+
         log.warning("Too many deadlocked robots. Trying new seed.")
         return await create_random_configuration(
             fps,
@@ -232,6 +244,7 @@ async def create_random_configuration(
             uniform=uniform,
             collision_buffer=collision_buffer,
             deadlock_retries=deadlock_retries,
+            n_failed=n_failed + 1,
         )
 
     if did_fail and n_deadlock > 0:
@@ -267,7 +280,7 @@ async def create_random_configuration(
                 }
             except JaegerError:
                 raise JaegerError(
-                    "Decollision failed. Cannot create random configuration."
+                    "Failed creating random configuration: cannot remove deadlocks."
                 )
 
             _, _, did_fail, deadlocks = await get_path_pair_in_executor(robot_grid)
@@ -357,3 +370,40 @@ def copy_summary_file(
 
     with open(new_path, "w") as f:
         f.write(summary_data)
+
+
+def read_confSummary(input: str | pathlib.Path | int, flavour: str = "") -> tuple:
+    """Reads a configuration summary file and returns the header and data frame."""
+
+    if isinstance(input, (str, pathlib.Path)):
+        path = input
+    else:
+        sdsscore_dir = pathlib.Path(os.environ["SDSSCORE_DIR"])
+        summary_files = sdsscore_dir / "apo" / "summary_files"
+        conf_xx = summary_files / f"{int(input/100):04d}XX"
+        path = conf_xx / f"confSummary{flavour}-{input}.par"
+
+    if not os.path.exists(str(path)):
+        raise FileNotFoundError(f"{path} does not exist.")
+
+    y = yanny(str(path))
+    header = dict(y)
+
+    fibermap = header.pop("FIBERMAP")
+    fibermap = fibermap[[col for col in fibermap.dtype.names if col != "mag"]]
+
+    df = pandas.DataFrame(fibermap)
+
+    for col in df.select_dtypes("object").columns:
+        df[col] = df[col].str.decode("utf-8")
+
+    for key, value in header.items():
+        try:
+            header[key] = int(value)
+        except ValueError:
+            try:
+                header[key] = float(value)
+            except ValueError:
+                pass
+
+    return header, df.set_index(["positionerId", "fiberType"])
